[![Documentation Status](https://readthedocs.org/projects/transcov/badge/?version=latest)](https://transcov.readthedocs.io/en/latest/?badge=latest) [![Build Status](https://travis-ci.org/Hogfeldt/transcov.svg?branch=master)](https://travis-ci.org/Hogfeldt/transcov)
[![install with bioconda](https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat)](http://bioconda.github.io/recipes/transcov/README.html)


# transcov
A bioinformatics software for mapping coverage around transcription start sites

For information on how it works and how to install and use. Please refer to the documentation, which can be found on [Read The Docs](https://transcov.readthedocs.io/en/stable/index.html).
